==> ak-lozenge-4.0.3.tgz: package/README.md <==
[![AtlasKit component registry](https://img.shields.io/badge/AtlasKit-components-FF5230.svg)](http://aui-cdn.atlassian.com/atlaskit/registry/)
[![Commitizen friendly](https://img.shields.io/badge/commitizen-friendly-brightgreen.svg)](http://Commitizen.github.io/cz-cli/)
[![semantic-release](https://img.shields.io/badge/GitHub-semantic_release-ffab00.svg)](https://github.com/semantic-release/semantic-release)
[![Report an issue](https://img.shields.io/badge/Report-an_issue-6554C0.svg)](https://ecosystem.atlassian.net/browse/AK)
[![Ask in our forum](https://img.shields.io/badge/Ask-in_our_forum-6554C0.svg)](https://answers.atlassian.com/questions/ask?title=AtlasKit%3A%20&topics=atlaskit,ak-lozenge,ak-lozenge@4.0.3)

# Lozenge

Use lozenges to highlight an item's status for quick recognition. Lozenges can be emphasised and can use color to help convey meanings that users can learn and recognize across our products. Use subtle lozenges by default and in instances where they may dominate the screen, such as in long tables.

![Example lozenge](https://bytebucket.org/atlassian/atlaskit/raw/3239a8d9ad5bb010ea787383e19b630918c1d78b/packages/ak-lozenge/docs/standard_lozenge.png)

![Example lozenge](https://bytebucket.org/atlassian/atlaskit/raw/3239a8d9ad5bb010ea787383e19b630918c1d78b/packages/ak-lozenge/docs/bold_lozenge.png)


## Try it out

Interact with a [live demo of the ak-lozenge component](https://aui-cdn.atlassian.com/atlaskit/stories/ak-lozenge/4.0.3/).

## Installation

```sh
npm install ak-lozenge
```

## Using the component

### HTML

The `ak-lozenge` package exports the Lozenge [Skate](https://github.com/skatejs/skatejs) component.

Import the component in your JS resource:

#### bundle.js

```js
import 'ak-lozenge';
```

Now you can use the defined tag in your HTML markup, for example
#### index.html

```html
<html>
<head>
  <script src="bundle.js"></script>
</head>
<body>
  <!-- ... -->
  <ak-lozenge appearance="moved" bold>Moved</ak-lozenge>
</body>
```

or from within another JavaScript resource:

```js
import Lozenge from 'ak-lozenge';

const component = new Lozenge();
document.body.appendChild(component);
```

### React

This is a standard web component, if you want to use it in your React app, use the Skate.js [React integration](https://github.com/webcomponents/react-integration).

```js
import Lozenge from 'ak-lozenge';
import reactify from 'skatejs-react-integration';

const ReactComponent = reactify(Lozenge, {});

ReactDOM.render(<ReactComponent />, container);
```

<a name="Lozenge"></a>

## Lozenge
**Kind**: global class  
<a name="new_Lozenge_new"></a>

### new Lozenge()
Create instances of the component programmatically, or using markup.

**JS Example**
```js
import Lozenge from 'ak-lozenge';
const component = new Lozenge();
```

## Support and feedback

### We're here to help!

Let us know what you think of our components and docs, your feedback is really important for us.

### Community support

Ask a question in our [forum](https://answers.atlassian.com/questions/ask?title=AtlasKit%3A%20&topics=atlaskit,ak-lozenge,ak-lozenge@4.0.3).

Check [if someone has already asked the same question before](https://answers.atlassian.com/questions/topics/42926171/atlaskit).


### Create a support ticket

Are you in trouble? [Let us know](https://ecosystem.atlassian.net/browse/AK)!

==> ak-lozenge-5.0.0.tgz: package/README.md <==
[![AtlasKit component registry](https://img.shields.io/badge/AtlasKit-components-FF5230.svg)](http://aui-cdn.atlassian.com/atlaskit/registry/)
[![Commitizen friendly](https://img.shields.io/badge/commitizen-friendly-brightgreen.svg)](http://Commitizen.github.io/cz-cli/)
[![semantic-release](https://img.shields.io/badge/GitHub-semantic_release-ffab00.svg)](https://github.com/semantic-release/semantic-release)
[![Report an issue](https://img.shields.io/badge/Report-an_issue-6554C0.svg)](https://ecosystem.atlassian.net/browse/AK)
[![Ask in our forum](https://img.shields.io/badge/Ask-in_our_forum-6554C0.svg)](https://answers.atlassian.com/questions/ask?title=AtlasKit%3A%20&topics=atlaskit,ak-lozenge,ak-lozenge@5.0.0)

# Lozenge

Use lozenges to highlight an item's status for quick recognition. Lozenges can be emphasised and can use color to help convey meanings that users can learn and recognize across our products. Use subtle lozenges by default and in instances where they may dominate the screen, such as in long tables.

![Example lozenge](https://bytebucket.org/atlassian/atlaskit/raw/43f19f96d12511939bb0233f590004c28acd1e19/packages/ak-lozenge/docs/standard_lozenge.png)

![Example lozenge](https://bytebucket.org/atlassian/atlaskit/raw/43f19f96d12511939bb0233f590004c28acd1e19/packages/ak-lozenge/docs/bold_lozenge.png)


## Try it out

Interact with a [live demo of the ak-lozenge component](https://aui-cdn.atlassian.com/atlaskit/stories/ak-lozenge/5.0.0/).

## Installation

```sh
npm install ak-lozenge
```

## Using the component

Import the component in your React app as follows:

```js
import Lozenge from 'ak-lozenge';
ReactDOM.render(<Lozenge />, container);
```



## Support and feedback

### We're here to help!

Let us know what you think of our components and docs, your feedback is really important for us.

### Community support

Ask a question in our [forum](https://answers.atlassian.com/questions/ask?title=AtlasKit%3A%20&topics=atlaskit,ak-lozenge,ak-lozenge@5.0.0).

Check [if someone has already asked the same question before](https://answers.atlassian.com/questions/topics/42926171/atlaskit).


### Create a support ticket

Are you in trouble? [Let us know](https://ecosystem.atlassian.net/browse/AK)!
